@@ -9,3 +9,7 @@ test_that("describe_trails", {
 test_that("list_public_keys", {
   expect_error(svc$list_public_keys(), NA)
 })
+
+test_that("list_trails", {
+  expect_error(svc$list_trails(), NA)
+})
